pub fn is_request_idempotent(request: &JsonRpcRequest) -> boolExpand description
Whether a request is safe to replay on another endpoint.
pub fn is_request_idempotent(request: &JsonRpcRequest) -> boolWhether a request is safe to replay on another endpoint.